@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
-__version__ = '0.2.3'
-__all__ = ['ApplicationMaster', 'HistoryServer', 'NodeManager',
-           'ResourceManager']
+__version__ = '1.0.3'
+__all__ = ['ApplicationMaster', 'HistoryServer', 'NodeManager', 'ResourceManager']
 
 from .application_master import ApplicationMaster
 from .history_server import HistoryServer
